@@ -2,12 +2,12 @@
 
 This module contains a linearized communication satellite model for analysis
 and control of orbital motion. The model includes three states:
-altitude to Earth radius ratio, satellite position and angular rotation velocity.
+radial position, radial velocity and angular velocity.
 
 Main components:
     - ComSat: Communication satellite model class in longitudinal channel
     - Linearized state matrices A, B, C, D for orbital dynamics
-    - Control input constraints (engine thrust)
+    - Control input constraints (tangential thrust u₂)
     - Methods for orbital motion simulation and attitude control
 """
 
@@ -34,17 +34,17 @@ class ComSat(ModelBase):
         dt (float, optional): Discretization frequency. Defaults to 0.01.
 
     Action space:
-        thrust: engine thrust
+        u2: tangential thrust (N) - positive accelerates satellite, negative decelerates
 
     State space:
-        rho: ratio of flight altitude to Earth radius
-        theta: satellite position relative to Earth coordinate system [rad]
-        omega: satellite angular rotation velocity [rad/s]
+        rho: radial position - distance from Earth center [km]
+        rho_dot: radial velocity [m/s]
+        theta_dot: angular velocity [rad/s]
 
     Output space:
-        rho: ratio of flight altitude to Earth radius
-        theta: satellite position relative to Earth coordinate system [rad]
-        omega: satellite angular rotation velocity [rad/s]
+        rho: radial position - distance from Earth center [km]
+        rho_dot: radial velocity [m/s]
+        theta_dot: angular velocity [rad/s]
     """
 
     def __init__(
@@ -69,11 +69,11 @@ class ComSat(ModelBase):
         self.discretisation_time = dt
 
         # Selected data for the system
-        self.selected_states = ["rho", "theta", "omega"]
-        self.selected_output = ["rho", "theta", "omega"]
+        self.selected_states = ["rho", "rho_dot", "theta_dot"]
+        self.selected_output = ["rho", "rho_dot", "theta_dot"]
         self.list_state = self.selected_states
         self.selected_input = [
-            "thrust",
+            "u2",
         ]
         self.control_list = self.selected_input
 
@@ -104,12 +104,21 @@ class ComSat(ModelBase):
         self.initialise_system(x0, number_time_steps)
 
     def import_linear_system(self):
-        """Сохраненные линеаризованные матрицы"""
+        """Load (set) stored linearized system matrices.
+
+        State vector: x = [x₁, x₃, x₄]ᵀ = [rho, rho_dot, theta_dot]ᵀ
+        Control: u = u₂ (tangential thrust)
+
+        Equations:
+        ẋ₁ = x₃  (radial position rate = radial velocity)
+        ẋ₃ = 0.01036·x₁ + 0.7753·x₄  (radial acceleration)
+        ẋ₄ = -0.01775·x₃ + 0.1513·u₂  (angular acceleration)
+        """
         self.A = np.array(
             [
                 [0.0, 1.0, 0.0],
-                [0.01036, 0, 0.7753],
-                [0, -0.1774, 0],
+                [0.01036, 0.0, 0.7753],
+                [0.0, -0.01775, 0.0],
             ]
         )
 
@@ -117,7 +126,7 @@ class ComSat(ModelBase):
             [
                 [0.0],
                 [0.0],
-                [0.1512],
+                [0.1513],
             ]
         )
 
@@ -138,11 +147,11 @@ class ComSat(ModelBase):
         )
 
     def initialise_system(self, x0, number_time_steps):
-        """Инициализация системы
+        """Initialize the system and allocate history buffers.
 
         Args:
-            x0 (_type_): Начальное состояние объекта управления
-            number_time_steps (_type_): количество временных шагов в итерации
+            x0: Initial state.
+            number_time_steps: Number of simulation steps.
         """
 
         # Import the stored system
@@ -171,13 +180,13 @@ class ComSat(ModelBase):
         )
 
     def run_step(self, ut_0: np.ndarray) -> np.ndarray:
-        """Выполняет один временной шаг итерации.
+        """Run one discrete-time simulation step.
 
         Args:
-            ut_0 (np.ndarray): Вектор управления
+            ut_0 (np.ndarray): Control vector.
 
         Returns:
-            xt1 (np.ndarray): Состояние объекта управления на шаге t+1
+            np.ndarray: Next state at time t+1.
         """
         if self.time_step != 0:
             ut_1 = self.store_input[:, self.time_step - 1]
@@ -238,35 +247,23 @@ class ComSat(ModelBase):
         return np.array(self.xt1)
 
     def update_system_attributes(self):
-        """Атрибуты, которые меняются с каждым временным шагом, обновляются"""
+        """Update time-dependent attributes after each simulation step."""
         self.xt = self.xt1
         self.time_step += 1
 
     def get_state(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив состояния
+        """Return the time history of a state.
 
         Args:
-            state_name: Название состояния
-            to_deg: Конвертировать в градусы
-            to_rad: Конвертировать в радианы
+            state_name: State name (e.g., ``rho``, ``rho_dot``, ``theta_dot``).
+            to_deg: Convert radians to degrees.
+            to_rad: Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного состояния
-
-        Пример:
-
-        >>> state_hist = model.get_state('alpha', to_deg=True)
-
+            np.ndarray: State history array.
         """
-        if state_name == "wz":
-            state_name = "theta"
-        if state_name == "wx":
-            state_name = "p"
-        if state_name == "wy":
-            state_name = "r"
         if state_name not in self.selected_states:
             raise Exception(
                 f"{state_name} нет в списке состояний, доступные {self.selected_states}"
@@ -281,29 +278,17 @@ class ComSat(ModelBase):
     def get_control(
         self, control_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив сигнала управления
+        """Return the time history of a control input.
 
         Args:
-            control_name: Название сигнала управления
-            to_deg: Конвертировать в градусы
+            control_name: Control name (e.g., ``u2``).
+            to_deg: Convert radians to degrees.
+            to_rad: Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного сигнала управления
-
-        Пример:
-
-        >>> state_hist = model.get_control('stab', to_deg=True)
+            np.ndarray: Control history array.
         """
-        if control_name in ["stab", "ele"]:
-            control_name = "ele"
-        if control_name in ["rud", "dir"]:
-            control_name = "rud"
-        if control_name not in self.selected_input or control_name not in [
-            "ele",
-            "ail",
-            "rud",
-        ]:
+        if control_name not in self.selected_input:
             raise Exception(
                 f"{control_name} нет в списке сигналов управления, доступные {self.selected_input}"
             )
@@ -317,19 +302,15 @@ class ComSat(ModelBase):
     def get_output(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив выходного сигнала
+        """Return the time history of an output signal.
 
         Args:
-            state_name (str): Название выходного сигнала
-            to_deg (bool): Конвертировать в градусы. Defaults to False.
-            to_rad (bool): Конвертировать в радианы. Defaults to False.
+            state_name (str): Output name.
+            to_deg (bool): Convert radians to degrees.
+            to_rad (bool): Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного выходного сигнала
-
-        Пример:
-        >>> output_hist = model.get_output('rho')
+            np.ndarray: Output history array.
         """
         self.output_history = output2dict(self.store_outputs, self.selected_output)
         if to_deg:
@@ -347,26 +328,18 @@ class ComSat(ModelBase):
         to_rad: bool = False,
         figsize: tuple = (10, 10),
     ) -> plt.Figure:
-        """
-        Построить график выходного сигнала
+        """Plot an output signal over time.
 
         Args:
-            output_name (str): Название выходного сигнала для построения графика
-            time (np.ndarray): Массив времени
-            lang (str): Язык подписей ("rus" или "eng"). Defaults to "rus".
-            to_deg (bool): Конвертировать в градусы. Defaults to False.
-            to_rad (bool): Конвертировать в радианы. Defaults to False.
-            figsize (tuple): Размер фигуры. Defaults to (10, 10).
+            output_name (str): Output name.
+            time (np.ndarray): Time vector.
+            lang (str): Axis label language ('rus' or 'eng'). Defaults to 'rus'.
+            to_deg (bool): Convert radians to degrees.
+            to_rad (bool): Convert degrees to radians.
+            figsize (tuple): Figure size.
 
         Returns:
-            matplotlib.figure.Figure: Объект фигуры matplotlib
-
-        Raises:
-            Exception: Если указаны одновременно to_rad и to_deg
-            Exception: Если output_name не найден в списке сигналов
-
-        Пример:
-        >>> fig = model.plot_output('rho', time_array)
+            matplotlib.figure.Figure: Figure object.
         """
         if to_rad and to_deg:
             raise Exception(
