@@ -14,22 +14,24 @@ class ELVRocket(ModelBase):
     Args:
         x0: Initial state of the control object.
         number_time_steps: Number of time steps.
-        selected_state_output (optional): Selected states of the control object. Defaults to None.
+        selected_state_output (optional): Selected states of the control
+            object. Defaults to None.
         t0 (int, optional): Initial time. Defaults to 0.
         dt (float, optional): Discretization frequency. Defaults to 0.01.
 
     Action space:
-        ele: elevator [deg]
+        ele: elevator [rad]
 
-    State space:
-        theta: Pitch [deg]
-        q: Pitch angular velocity [deg/s]
+    State space (order):
         w: Longitudinal aircraft velocity [m/s]
+        q: Pitch angular velocity [rad/s]
+        theta: Pitch [rad]
 
-    Output space:
-        theta: Pitch [deg]
-        q: Pitch angular velocity [deg/s]
+
+    Output space (order):
         w: Longitudinal aircraft velocity [m/s]
+        q: Pitch angular velocity [rad/s]
+        theta: Pitch [rad]
     """
 
     def __init__(
@@ -45,8 +47,8 @@ class ELVRocket(ModelBase):
         self.discretisation_time = dt
 
         # Selected data for the system
-        self.selected_states = ["theta", "q", "w"]
-        self.selected_output = ["theta", "q", "w"]
+        self.selected_states = ["w", "q", "theta"]
+        self.selected_output = ["w", "q", "theta"]
         self.list_state = self.selected_states
         self.selected_input = [
             "ele",
@@ -57,13 +59,13 @@ class ELVRocket(ModelBase):
 
         self.state_space = self.selected_states
         self.action_space = self.selected_input
-        # ele
+        # ele (radians)
         # Limitations of the system
         self.input_magnitude_limits = [
-            25,
+            float(np.deg2rad(25.0)),
         ]
         self.input_rate_limits = [
-            60,
+            float(np.deg2rad(60.0)),
         ]
 
         # Store the number of inputs, states and outputs
@@ -80,8 +82,14 @@ class ELVRocket(ModelBase):
         self.initialise_system(x0, number_time_steps)
 
     def import_linear_system(self) -> None:
-        """Сохраненные линеаризованные матрицы"""
-        self.A = np.array(
+        """Load (set) stored linearized system matrices.
+
+        The original matrices are defined for the legacy state order
+        ``[alpha, q, theta]`` and are converted to the current order
+        ``[w, q, theta]`` using a permutation matrix.
+        """
+        # Old-order matrices: x_old = [alpha, q, theta]
+        A_old = np.array(
             [
                 [-100.858, 1, -0.1256],
                 [14.7805, 0, 0.01958],
@@ -89,7 +97,7 @@ class ELVRocket(ModelBase):
             ]
         )
 
-        self.B = np.array(
+        B_old = np.array(
             [
                 [20.42],
                 [3.4558],
@@ -97,28 +105,32 @@ class ELVRocket(ModelBase):
             ]
         )
 
-        self.C = np.array(
+        # Permutation from new -> old basis
+        # new = [w, q, theta] corresponds to old = [alpha, q, theta]
+        # so indices: old[0]=alpha->new[0]=w, old[1]=q->new[1]=q,
+        # old[2]=theta->new[2]=theta. P[i,j] = 1 if old[i] = new[j]
+        P = np.array(
             [
-                [1, 0, 0],
-                [0, 1, 0],
-                [0, 0, 1],
+                [1, 0, 0],  # alpha_old = w_new
+                [0, 1, 0],  # q_old = q_new
+                [0, 0, 1],  # theta_old = theta_new
             ]
         )
 
-        self.D = np.array(
-            [
-                [0],
-                [0],
-                [0],
-            ]
-        )
+        # Transform to new basis: A_new = P^T A_old P, B_new = P^T B_old
+        self.A = P.T @ A_old @ P
+        self.B = P.T @ B_old
+
+        # Identity output in new basis
+        self.C = np.eye(3)
+        self.D = np.zeros((3, 1))
 
     def initialise_system(self, x0, number_time_steps) -> None:
-        """Инициализация системы
+        """Initialize the system and allocate history buffers.
 
         Args:
-            x0 (_type_): Начальное состояние объекта управления
-            number_time_steps (_type_): количество временных шагов в итерации
+            x0: Initial state.
+            number_time_steps: Number of simulation steps.
         """
 
         # Import the stored system
@@ -147,13 +159,13 @@ class ELVRocket(ModelBase):
         )
 
     def run_step(self, ut_0: np.ndarray) -> np.ndarray:
-        """Выполняет один временной шаг итерации.
+        """Run one discrete-time simulation step.
 
         Args:
-            ut_0 (np.ndarray): Вектор управления
+            ut_0 (np.ndarray): Control vector.
 
         Returns:
-            xt1 (np.ndarray): Состояние объекта управления на шаге t+1
+            np.ndarray: Next state at time t+1.
         """
         if self.time_step != 0:
             ut_1 = self.store_input[:, self.time_step - 1]
@@ -214,28 +226,22 @@ class ELVRocket(ModelBase):
         return np.array(self.xt1)
 
     def update_system_attributes(self) -> None:
-        """Атрибуты, которые меняются с каждым временным шагом, обновляются"""
+        """Update time-dependent attributes after each simulation step."""
         self.xt = self.xt1
         self.time_step += 1
 
     def get_state(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив состояния
+        """Return the time history of a state.
 
         Args:
-            state_name: Название состояния
-            to_deg: Конвертировать в градусы
-            to_rad: Конвертировать в радианы
+            state_name: State name.
+            to_deg: Convert radians to degrees.
+            to_rad: Convert degrees to radians.
 
         Returns:
-            Массив истории выбранного состояния
-
-        Пример:
-
-        >>> state_hist = model.get_state('alpha', to_deg=True)
-
+            np.ndarray: State history array.
         """
         if state_name == "wz":
             state_name = "q"
@@ -257,19 +263,15 @@ class ELVRocket(ModelBase):
     def get_control(
         self, control_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив сигнала управления
+        """Return the time history of a control input.
 
         Args:
-            control_name: Название сигнала управления
-            to_deg: Конвертировать в градусы
+            control_name: Control signal name.
+            to_deg: Convert radians to degrees.
+            to_rad: Convert degrees to radians.
 
         Returns:
-            Массив истории выбранного сигнала управления
-
-        Пример:
-
-        >>> state_hist = model.get_control('stab', to_deg=True)
+            np.ndarray: Control history array.
         """
         if control_name in ["stab", "ele"]:
             control_name = "ele"
@@ -293,19 +295,15 @@ class ELVRocket(ModelBase):
     def get_output(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив выходного сигнала
+        """Return the time history of an output signal.
 
         Args:
-            state_name (str): Название выходного сигнала
-            to_deg (bool): Конвертировать в градусы. Defaults to False.
-            to_rad (bool): Конвертировать в радианы. Defaults to False.
+            state_name (str): Output name.
+            to_deg (bool): Convert radians to degrees.
+            to_rad (bool): Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного выходного сигнала
-
-        Пример:
-        >>> output_hist = model.get_output('theta')
+            np.ndarray: Output history array.
         """
         self.output_history = output2dict(self.store_outputs, self.selected_output)
         if to_deg:
@@ -323,26 +321,18 @@ class ELVRocket(ModelBase):
         to_rad: bool = False,
         figsize: tuple = (10, 10),
     ) -> Figure:
-        """
-        Построить график выходного сигнала
+        """Plot an output signal over time.
 
         Args:
-            output_name (str): Название выходного сигнала для построения графика
-            time (np.ndarray): Массив времени
-            lang (str): Язык подписей ("rus" или "eng"). Defaults to "rus".
-            to_deg (bool): Конвертировать в градусы. Defaults to False.
-            to_rad (bool): Конвертировать в радианы. Defaults to False.
-            figsize (tuple): Размер фигуры. Defaults to (10, 10).
+            output_name (str): Output name.
+            time (np.ndarray): Time vector.
+            lang (str): Axis label language ('rus' or 'eng'). Defaults to 'rus'.
+            to_deg (bool): Convert radians to degrees.
+            to_rad (bool): Convert degrees to radians.
+            figsize (tuple): Figure size.
 
         Returns:
-            matplotlib.figure.Figure: Объект фигуры matplotlib
-
-        Raises:
-            Exception: Если указаны одновременно to_rad и to_deg
-            Exception: Если output_name не найден в списке сигналов
-
-        Пример:
-        >>> fig = model.plot_output('theta', time_array)
+            matplotlib.figure.Figure: Figure object.
         """
         if to_rad and to_deg:
             raise Exception(
