@@ -21,19 +21,19 @@ class LongitudinalF4C(ModelBase):
         dt (float, optional): Discretization frequency. Defaults to 0.01.
 
     Action space:
-        ele: elevator [deg]
+        ele: elevator [rad]
 
     State space:
-        u: Longitudinal aircraft velocity [m/s]
-        w: Normal aircraft velocity [m/s]
-        q: Pitch angular velocity [deg/s]
-        theta: Pitch [deg]
+        u: Longitudinal aircraft velocity [ft/s]
+        w: Normal aircraft velocity [ft/s]
+        q: Pitch angular velocity [rad/s]
+        theta: Pitch angle [rad]
 
     Output space:
-        u: Longitudinal aircraft velocity [m/s]
-        w: Normal aircraft velocity [m/s]
-        q: Pitch angular velocity [deg/s]
-        theta: Pitch [deg]
+        u: Longitudinal aircraft velocity [ft/s]
+        w: Normal aircraft velocity [ft/s]
+        q: Pitch angular velocity [rad/s]
+        theta: Pitch angle [rad]
     """
 
     def __init__(
@@ -71,12 +71,13 @@ class LongitudinalF4C(ModelBase):
         self.state_space = self.selected_states
         self.action_space = self.selected_input
         # ele
-        # Limitations of the system
+        # Limitations of the system (model works in radians)
+        # Magnitude: ±20 deg -> radians; Rate: ±60 deg/s -> rad/s
         self.input_magnitude_limits = [
-            25,
+            float(np.deg2rad(20.0)),
         ]
         self.input_rate_limits = [
-            60,
+            float(np.deg2rad(60.0)),
         ]
 
         # Store the number of inputs, states and outputs
@@ -99,17 +100,17 @@ class LongitudinalF4C(ModelBase):
         self.initialise_system(x0, number_time_steps)
 
     def import_linear_system(self):
-        """Сохраненные линеаризованные матрицы"""
+        """Load (set) stored linearized system matrices."""
         self.A = np.array(
             [
-                [-0.00679, 0.00146, 0, -32.174],
-                [0.0110, -0.4940, 1469.7600, 0],
-                [0.003410, -0.019781184, -0.4879811, 0],
-                [0, 0, 1, 0],
+                [7.6180e-04, 4.7612e-03, 0.0000e00, -9.8100e00],
+                [-6.6657e-02, -2.8567e-01, 1.8000e02, 0.0000e00],
+                [1.5124e-03, -1.0083e-02, -1.6384e-01, 0.0000e00],
+                [0.0000e00, 0.0000e00, 1.0000e00, 0.0000e00],
             ]
         )
 
-        self.B = np.array([[0.0027], [-0.0584], [-0.0001309], [0]])
+        self.B = np.array([[0.0026532701], [-6.8562], [-5.4446], [0.00000000]])
 
         self.C = np.array(
             [
@@ -130,11 +131,11 @@ class LongitudinalF4C(ModelBase):
         )
 
     def initialise_system(self, x0, number_time_steps):
-        """Инициализация системы
+        """Initialize the system and allocate history buffers.
 
         Args:
-            x0 (_type_): Начальное состояние объекта управления
-            number_time_steps (_type_): количество временных шагов в итерации
+            x0: Initial state.
+            number_time_steps: Number of simulation steps.
         """
 
         # Import the stored system
@@ -163,13 +164,13 @@ class LongitudinalF4C(ModelBase):
         )
 
     def run_step(self, ut_0: np.ndarray) -> np.ndarray:
-        """Выполняет один временной шаг итерации.
+        """Run one discrete-time simulation step.
 
         Args:
-            ut_0 (np.ndarray): Вектор управления
+            ut_0 (np.ndarray): Control vector.
 
         Returns:
-            xt1 (np.ndarray): Состояние объекта управления на шаге t+1
+            np.ndarray: Next state at time t+1.
         """
         if self.time_step != 0:
             ut_1 = self.store_input[:, self.time_step - 1]
@@ -231,28 +232,22 @@ class LongitudinalF4C(ModelBase):
         return np.array(self.xt1)
 
     def update_system_attributes(self):
-        """Атрибуты, которые меняются с каждым временным шагом, обновляются"""
+        """Update time-dependent attributes after each simulation step."""
         self.xt = self.xt1
         self.time_step += 1
 
     def get_state(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив состояния
+        """Return the time history of a state.
 
         Args:
-            state_name: Название состояния
-            to_deg: Конвертировать в градусы
-            to_rad: Конвертировать в радианы
+            state_name: State name.
+            to_deg: Convert radians to degrees.
+            to_rad: Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного состояния
-
-        Пример:
-
-        >>> state_hist = model.get_state('alpha', to_deg=True)
-
+            np.ndarray: State history array.
         """
         if state_name == "wz":
             state_name = "q"
@@ -274,19 +269,15 @@ class LongitudinalF4C(ModelBase):
     def get_control(
         self, control_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив сигнала управления
+        """Return the time history of a control input.
 
         Args:
-            control_name: Название сигнала управления
-            to_deg: Конвертировать в градусы
+            control_name: Control signal name.
+            to_deg: Convert radians to degrees.
+            to_rad: Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного сигнала управления
-
-        Пример:
-
-        >>> state_hist = model.get_control('stab', to_deg=True)
+            np.ndarray: Control history array.
         """
         if control_name in ["stab", "ele"]:
             control_name = "ele"
@@ -310,19 +301,15 @@ class LongitudinalF4C(ModelBase):
     def get_output(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив выходного сигнала
+        """Return the time history of an output signal.
 
         Args:
-            state_name (str): Название выходного сигнала
-            to_deg (bool): Конвертировать в градусы. Defaults to False.
-            to_rad (bool): Конвертировать в радианы. Defaults to False.
+            state_name (str): Output name.
+            to_deg (bool): Convert radians to degrees.
+            to_rad (bool): Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного выходного сигнала
-
-        Пример:
-        >>> output_hist = model.get_output('u')
+            np.ndarray: Output history array.
         """
         self.output_history = output2dict(self.store_outputs, self.selected_output)
         if to_deg:
@@ -340,26 +327,18 @@ class LongitudinalF4C(ModelBase):
         to_rad: bool = False,
         figsize: tuple = (10, 10),
     ) -> plt.Figure:
-        """
-        Построить график выходного сигнала
+        """Plot an output signal over time.
 
         Args:
-            output_name (str): Название выходного сигнала для построения графика
-            time (np.ndarray): Массив времени
-            lang (str): Язык подписей ("rus" или "eng"). Defaults to "rus".
-            to_deg (bool): Конвертировать в градусы. Defaults to False.
-            to_rad (bool): Конвертировать в радианы. Defaults to False.
-            figsize (tuple): Размер фигуры. Defaults to (10, 10).
+            output_name (str): Output name.
+            time (np.ndarray): Time vector.
+            lang (str): Axis label language ('rus' or 'eng'). Defaults to 'rus'.
+            to_deg (bool): Convert radians to degrees.
+            to_rad (bool): Convert degrees to radians.
+            figsize (tuple): Figure size.
 
         Returns:
-            matplotlib.figure.Figure: Объект фигуры matplotlib
-
-        Raises:
-            Exception: Если указаны одновременно to_rad и to_deg
-            Exception: Если output_name не найден в списке сигналов
-
-        Пример:
-        >>> fig = model.plot_output('u', time_array)
+            matplotlib.figure.Figure: Figure object.
         """
         if to_rad and to_deg:
             raise Exception(
