@@ -91,7 +91,7 @@ class MissileModel(ModelBase):
         self.initialise_system(x0, number_time_steps)
 
     def import_linear_system(self) -> None:
-        """Сохраненные линеаризованные матрицы"""
+        """Load stored linearized matrices."""
         self.A = np.array(
             [
                 [-0.0089, -0.1474, 0.0, -9.75],
@@ -129,11 +129,11 @@ class MissileModel(ModelBase):
         )
 
     def initialise_system(self, x0, number_time_steps) -> None:
-        """Инициализация системы
+        """Initialize the system.
 
         Args:
-            x0 (_type_): Начальное состояние объекта управления
-            number_time_steps (_type_): количество временных шагов в итерации
+            x0: Initial state of the control object.
+            number_time_steps: Number of time steps in the iteration.
         """
 
         # Import the stored system
@@ -229,28 +229,25 @@ class MissileModel(ModelBase):
         return np.array(self.xt1)
 
     def update_system_attributes(self) -> None:
-        """Атрибуты, которые меняются с каждым временным шагом, обновляются"""
+        """Update attributes that change with each time step."""
         self.xt = self.xt1
         self.time_step += 1
 
     def get_state(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив состояния
+        """Get state array history.
 
         Args:
-            state_name: Название состояния
-            to_deg: Конвертировать в градусы
-            to_rad: Конвертировать в радианы
+            state_name (str): State name.
+            to_deg (bool): Convert to degrees. Defaults to False.
+            to_rad (bool): Convert to radians. Defaults to False.
 
         Returns:
-            Массив истории выбранного состояния
-
-        Пример:
-
-        >>> state_hist = model.get_state('alpha', to_deg=True)
+            np.ndarray: Array of selected state history.
 
+        Example:
+            >>> state_hist = model.get_state('alpha', to_deg=True)
         """
         if state_name == "wz":
             state_name = "q"
@@ -272,19 +269,18 @@ class MissileModel(ModelBase):
     def get_control(
         self, control_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив сигнала управления
+        """Get control signal array history.
 
         Args:
-            control_name: Название сигнала управления
-            to_deg: Конвертировать в градусы
+            control_name (str): Control signal name.
+            to_deg (bool): Convert to degrees. Defaults to False.
+            to_rad (bool): Convert to radians. Defaults to False.
 
         Returns:
-            Массив истории выбранного сигнала управления
+            np.ndarray: Array of selected control signal history.
 
-        Пример:
-
-        >>> state_hist = model.get_control('stab', to_deg=True)
+        Example:
+            >>> control_hist = model.get_control('stab', to_deg=True)
         """
         if control_name in ["stab", "ele"]:
             control_name = "ele"
@@ -308,18 +304,17 @@ class MissileModel(ModelBase):
     def get_output(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив выходного сигнала
+        """Get output signal array history.
 
         Args:
-            state_name (str): Название выходного сигнала
-            to_deg (bool): Конвертировать в градусы
-            to_rad (bool): Конвертировать в радианы
+            state_name (str): Output signal name.
+            to_deg (bool): Convert to degrees. Defaults to False.
+            to_rad (bool): Convert to radians. Defaults to False.
 
         Returns:
-            np.ndarray: Массив истории выбранного выходного сигнала
+            np.ndarray: Array of selected output signal history.
 
-        Пример:
+        Example:
             >>> output_hist = model.get_output('alpha', to_deg=True)
         """
         self.output_history = output2dict(self.store_outputs, self.selected_output)
@@ -338,24 +333,23 @@ class MissileModel(ModelBase):
         to_rad: bool = False,
         figsize: tuple = (10, 10),
     ) -> Figure:
-        """
-        Построить график выходного сигнала
+        """Plot output signal.
 
         Args:
-            output_name (str): Название выходного сигнала
-            time (np.ndarray): Массив времени
-            lang (str): Язык подписей ('rus' или 'eng')
-            to_deg (bool): Конвертировать в градусы
-            to_rad (bool): Конвертировать в радианы
-            figsize (tuple): Размер фигуры
+            output_name (str): Output signal name.
+            time (np.ndarray): Time array.
+            lang (str): Label language ('rus' or 'eng'). Defaults to "rus".
+            to_deg (bool): Convert to degrees. Defaults to False.
+            to_rad (bool): Convert to radians. Defaults to False.
+            figsize (tuple): Figure size. Defaults to (10, 10).
 
         Returns:
-            matplotlib.figure.Figure: Объект фигуры matplotlib
+            Figure: Matplotlib figure object.
 
         Raises:
-            Exception: Если указаны одновременно to_rad и to_deg или неверное имя сигнала
+            Exception: If both to_rad and to_deg are specified, or if output_name is invalid.
 
-        Пример:
+        Example:
             >>> fig = model.plot_output('alpha', time_array, lang='rus', to_deg=True)
         """
         if to_rad and to_deg:
