@@ -8,27 +8,25 @@ from tensoraerospace.aerospacemodel.utils import state_to_latex_eng, state_to_la
 
 
 class LongitudinalSuperSonic(ModelBase):
-    r"""
-    Сверхзвуковой самолет в изолированном боковом канале.
+    """Supersonic aircraft in isolated longitudinal channel.
 
-    Пространство действий:
-        * ele: руль высоты [град]
+    Action space:
+        * ele: elevator [deg]
 
+    State space:
+        * u: Longitudinal velocity [m/s]
+        * w: Normal velocity [m/s]
+        * q: Pitch angular velocity [deg/s]
+        * theta: Pitch angle [deg]
 
-    Пространство состояний:
-        * $u$ - Продольная скорость ЛА [м/с]
-        * $w$ - Нормальная скорость ЛА [м/с]
-        * $q$ - Угловая скорость Тангажа [град/с]
-        * $\theta$ - Тангаж [град]
-
-    Пространство выхода:
-        * $q$ - Угловая скорость Тангажа [град/с]
-        * $\theta$ - Тангаж  [град]
-        * $\alpha$ - Угол атаки  [град]
-        * $u$ - Продольная скорость ЛА [м/с]
-        * $\alpha_{zcg}$ - нормальное ускорение в CG (центре масс) [м/с^2]
-        * $\alpha_{zp}$ - нормальное ускорение на станции пилота [м/с^2]
-        * $\gamma$ - Угол траектории полета [град]
+    Output space:
+        * q: Pitch angular velocity [deg/s]
+        * theta: Pitch angle [deg]
+        * alpha: Angle of attack [deg]
+        * u: Longitudinal velocity [m/s]
+        * a_zcg: Normal acceleration at CG (center of mass) [m/s^2]
+        * a_zp: Normal acceleration at pilot station [m/s^2]
+        * gamma: Flight path angle [deg]
     """
 
     def __init__(
@@ -223,21 +221,18 @@ class LongitudinalSuperSonic(ModelBase):
         self.time_step += 1
 
     def get_state(self, state_name: str, to_deg: bool = False, to_rad: bool = False):
-        """
-        Получить массив состояния
+        """Get state array history.
 
         Args:
-            state_name: Название состояния
-            to_deg: Конвертировать в градусы
-            to_rad: Конвертировать в радианы
+            state_name (str): State name.
+            to_deg (bool): Convert to degrees. Defaults to False.
+            to_rad (bool): Convert to radians. Defaults to False.
 
         Returns:
-            Массив истории выбранного состояния
-
-        Пример:
-
-        >>> state_hist = model.get_state('alpha', to_deg=True)
+            np.ndarray: Array of selected state history.
 
+        Example:
+            >>> state_hist = model.get_state('alpha', to_deg=True)
         """
         if state_name == "wz":
             state_name = "q"
@@ -259,19 +254,18 @@ class LongitudinalSuperSonic(ModelBase):
     def get_control(
         self, control_name: str, to_deg: bool = False, to_rad: bool = False
     ):
-        """
-        Получить массив сигнала управления
+        """Get control signal array history.
 
         Args:
-            control_name: Название сигнала управления
-            to_deg: Конвертировать в градусы
+            control_name (str): Control signal name.
+            to_deg (bool): Convert to degrees. Defaults to False.
+            to_rad (bool): Convert to radians. Defaults to False.
 
         Returns:
-            Массив истории выбранного сигнала управления
+            np.ndarray: Array of selected control signal history.
 
-        Пример:
-
-        >>> state_hist = model.get_control('stab', to_deg=True)
+        Example:
+            >>> control_hist = model.get_control('stab', to_deg=True)
         """
         if control_name in ["stab", "ele"]:
             control_name = "ele"
@@ -293,18 +287,17 @@ class LongitudinalSuperSonic(ModelBase):
         return self.store_input[index][: self.number_time_steps - 1]
 
     def get_output(self, state_name: str, to_deg: bool = False, to_rad: bool = False):
-        """
-        Получить массив выходного сигнала
+        """Get output signal array history.
 
         Args:
-            state_name (str): Название выходного сигнала
-            to_deg (bool): Конвертировать в градусы
-            to_rad (bool): Конвертировать в радианы
+            state_name (str): Output signal name.
+            to_deg (bool): Convert to degrees. Defaults to False.
+            to_rad (bool): Convert to radians. Defaults to False.
 
         Returns:
-            np.ndarray: Массив истории выбранного выходного сигнала
+            np.ndarray: Array of selected output signal history.
 
-        Пример:
+        Example:
             >>> output_hist = model.get_output('alpha', to_deg=True)
         """
         self.output_history = output2dict(self.store_outputs, self.selected_output)
@@ -323,24 +316,23 @@ class LongitudinalSuperSonic(ModelBase):
         to_rad: bool = False,
         figsize: tuple = (10, 10),
     ):
-        """
-        Построить график выходного сигнала
+        """Plot output signal.
 
         Args:
-            output_name (str): Название выходного сигнала
-            time (np.ndarray): Массив времени
-            lang (str): Язык подписей ('rus' или 'eng')
-            to_deg (bool): Конвертировать в градусы
-            to_rad (bool): Конвертировать в радианы
-            figsize (tuple): Размер фигуры
+            output_name (str): Output signal name.
+            time (np.ndarray): Time array.
+            lang (str): Label language ('rus' or 'eng'). Defaults to "rus".
+            to_deg (bool): Convert to degrees. Defaults to False.
+            to_rad (bool): Convert to radians. Defaults to False.
+            figsize (tuple): Figure size. Defaults to (10, 10).
 
         Returns:
-            matplotlib.figure.Figure: Объект фигуры matplotlib
+            plt.Figure: Matplotlib figure object.
 
         Raises:
-            Exception: Если указаны одновременно to_rad и to_deg или неверное имя сигнала
+            Exception: If both to_rad and to_deg are specified, or if output_name is invalid.
 
-        Пример:
+        Example:
             >>> fig = model.plot_output('alpha', time_array, lang='rus', to_deg=True)
         """
         if to_rad and to_deg:
