@@ -21,21 +21,21 @@ class Ultrastick(ModelBase):
         dt (float, optional): Discretization frequency. Defaults to 0.01.
 
     Action space:
-        ele: Elevator [deg]
-        delta_t: Engine throttle stick deflection angle [deg]
+        ele: Elevator [rad]
+        delta_t: Dimensionless value, 0 — off, 1 — max thrust
 
     State space:
         u: Longitudinal aircraft velocity [m/s]
         w: Normal aircraft velocity [m/s]
-        q: Pitch angular velocity [deg/s]
-        theta: Pitch [deg]
+        q: Pitch angular velocity [rad/s]
+        theta: Pitch [rad]
         h: Altitude [m]
 
     Output space:
         u: Longitudinal aircraft velocity [m/s]
         w: Normal aircraft velocity [m/s]
-        q: Pitch angular velocity [deg/s]
-        theta: Pitch [deg]
+        q: Pitch angular velocity [rad/s]
+        theta: Pitch [rad]
         h: Altitude [m]
     """
 
@@ -63,9 +63,10 @@ class Ultrastick(ModelBase):
         self.state_space = self.selected_states
         self.action_space = self.selected_input
         # ele
-        # Limitations of the system
-        self.input_magnitude_limits = [25, 25]
-        self.input_rate_limits = [60, 60]
+        # Limitations of the system (SI units)
+        # ele (radians), delta_t (dimensionless)
+        self.input_magnitude_limits = [np.deg2rad(30), 1]
+        self.input_rate_limits = [np.deg2rad(300), 10000]
 
         # Store the number of inputs, states and outputs
         self.number_inputs = len(self.selected_input)
@@ -87,26 +88,26 @@ class Ultrastick(ModelBase):
         self.initialise_system(x0, number_time_steps)
 
     def import_linear_system(self):
-        """Сохраненные линеаризованные матрицы"""
+        """Load (set) stored linearized system matrices."""
         self.A = np.array(
             [
-                [-0.5944, 0.8008, -9.791, -0.8747, 5.077 * (10**-5)],
-                [-0.744, -7.56, -0.5294, 15.72, -0.000939],
+                [-0.5944, -0.8008, 9.791, -0.8747, 5.077e-5],
+                [-0.744, -7.56, 0.5294, -1.572, 0.000939],
                 [0, 0, 0, 1, 0],
-                [1.041, -7.406, 0, -15.81, -7.284 * (10**-18)],
-                [-0.05399, 0.9985, -17, 0, 0],
+                [1.041, -7.406, 0, 0, 0],
+                [-15.81, -7.284e-3, 0.05399, -0.9985, 0],
             ]
         )
 
-        self.B = np.array([[0.4669, 0], [-2.703, 0], [0, 0], [-133.7, 0], [0, 0]])
+        self.B = np.array([[0.4669, 0], [2.703, 0], [0, 0], [133.7, 0], [0, 1]])
 
         self.C = np.array(
             [
-                [1, 0, 0, 0, 0],
-                [0, 1, 0, 0, 0],
-                [0, 0, 1, 0, 0],
-                [0, 0, 0, 1, 0],
-                [0, 0, 0, 0, 1],
+                [0.9985, 0.05399, 0, 0, 0],  # Va
+                [0.003176, 0.05874, 0, 0, 0],  # alpha
+                [0, 0, 1, 0, 0],  # theta
+                [0, 0, 0, 1, 0],  # pitch rate (q)
+                [0, 0, 0, 0, 1],  # altitude (h)
             ]
         )
 
@@ -121,11 +122,11 @@ class Ultrastick(ModelBase):
         )
 
     def initialise_system(self, x0, number_time_steps):
-        """Инициализация системы
+        """Initialize the system and allocate history buffers.
 
         Args:
-            x0 (_type_): Начальное состояние объекта управления
-            number_time_steps (_type_): количество временных шагов в итерации
+            x0: Initial state.
+            number_time_steps: Number of simulation steps.
         """
 
         # Import the stored system
@@ -154,52 +155,33 @@ class Ultrastick(ModelBase):
         )
 
     def run_step(self, ut_0: np.ndarray) -> np.ndarray:
-        """Выполняет один временной шаг итерации.
+        """Run one discrete-time simulation step.
 
         Args:
-            ut_0 (np.ndarray): Вектор управления
+            ut_0 (np.ndarray): Control vector.
 
         Returns:
-            xt1 (np.ndarray): Состояние объекта управления на шаге t+1
+            np.ndarray: System output at the current step (via C/D).
         """
+        # Ensure 1D float control vector
+        ut_0 = np.asarray(ut_0, dtype=float).reshape(-1)
         if self.time_step != 0:
-            ut_1 = self.store_input[:, self.time_step - 1]
+            ut_1 = np.asarray(
+                self.store_input[:, self.time_step - 1], dtype=float
+            ).reshape(-1)
         else:
-            ut_1 = ut_0
-        ut = [0, 0]
+            ut_1 = ut_0.copy()
+
+        # Rate and magnitude limiting (scalar clipping)
+        ut = ut_0.copy()
         for i in range(self.number_inputs):
-            ut[i] = max(
-                min(
-                    max(
-                        min(
-                            ut_0[i],
-                            np.reshape(
-                                np.array(
-                                    [
-                                        ut_1[i]
-                                        + self.input_rate_limits[i]
-                                        * self.discretisation_time
-                                    ]
-                                ),
-                                [-1, 1],
-                            ),
-                        ),
-                        np.reshape(
-                            np.array(
-                                [
-                                    ut_1[i]
-                                    - self.input_rate_limits[i]
-                                    * self.discretisation_time
-                                ]
-                            ),
-                            [-1, 1],
-                        ),
-                    ),
-                    np.array([[self.input_magnitude_limits[i]]]),
-                ),
-                -np.array([[self.input_magnitude_limits[i]]]),
-            )
-        ut = np.array(ut)
+            rate = float(self.input_rate_limits[i]) * float(self.discretisation_time)
+            low_rate = float(ut_1[i] - rate)
+            high_rate = float(ut_1[i] + rate)
+            ut[i] = float(np.clip(float(ut[i]), low_rate, high_rate))
+            amp = float(self.input_magnitude_limits[i])
+            ut[i] = float(np.clip(float(ut[i]), -amp, amp))
+        ut = np.asarray(ut, dtype=float).reshape(-1)
         self.xt1 = np.matmul(self.filt_A, np.reshape(self.xt, [-1, 1])) + np.matmul(
             self.filt_B, np.reshape(ut, [-1, 1])
         )
@@ -214,33 +196,28 @@ class Ultrastick(ModelBase):
         )
 
         self.update_system_attributes()
+        output_flat = np.reshape(output, [output.shape[0]])
         if self.selected_state_output:
-            return np.array(self.xt1[self.selected_state_index])
-        return np.array(self.xt1)
+            return np.array(output_flat[self.selected_state_index])
+        return output_flat
 
     def update_system_attributes(self):
-        """Атрибуты, которые меняются с каждым временным шагом, обновляются"""
+        """Update time-dependent attributes after each simulation step."""
         self.xt = self.xt1
         self.time_step += 1
 
     def get_state(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив состояния
+        """Return the time history of a state.
 
         Args:
-            state_name: Название состояния
-            to_deg: Конвертировать в градусы
-            to_rad: Конвертировать в радианы
+            state_name: State name.
+            to_deg: Convert radians to degrees.
+            to_rad: Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного состояния
-
-        Пример:
-
-        >>> state_hist = model.get_state('alpha', to_deg=True)
-
+            np.ndarray: State history array.
         """
         if state_name == "wz":
             state_name = "q"
@@ -262,19 +239,15 @@ class Ultrastick(ModelBase):
     def get_control(
         self, control_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив сигнала управления
+        """Return the time history of a control input.
 
         Args:
-            control_name: Название сигнала управления
-            to_deg: Конвертировать в градусы
+            control_name: Control signal name.
+            to_deg: Convert radians to degrees.
+            to_rad: Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного сигнала управления
-
-        Пример:
-
-        >>> state_hist = model.get_control('stab', to_deg=True)
+            np.ndarray: Control history array.
         """
         if control_name in ["stab", "ele"]:
             control_name = "ele"
@@ -298,19 +271,15 @@ class Ultrastick(ModelBase):
     def get_output(
         self, state_name: str, to_deg: bool = False, to_rad: bool = False
     ) -> np.ndarray:
-        """
-        Получить массив выходного сигнала
+        """Return the time history of an output signal.
 
         Args:
-            state_name (str): Название выходного сигнала
-            to_deg (bool): Конвертировать в градусы
-            to_rad (bool): Конвертировать в радианы
+            state_name (str): Output name.
+            to_deg (bool): Convert radians to degrees.
+            to_rad (bool): Convert degrees to radians.
 
         Returns:
-            np.ndarray: Массив истории выбранного выходного сигнала
-
-        Пример:
-            >>> output_hist = model.get_output('alpha', to_deg=True)
+            np.ndarray: Output history array.
         """
         self.output_history = output2dict(self.store_outputs, self.selected_output)
         if to_deg:
@@ -328,25 +297,18 @@ class Ultrastick(ModelBase):
         to_rad: bool = False,
         figsize: tuple = (10, 10),
     ) -> plt.Figure:
-        """
-        Построить график выходного сигнала
+        """Plot an output signal over time.
 
         Args:
-            output_name (str): Название выходного сигнала
-            time (np.ndarray): Массив времени
-            lang (str): Язык подписей ('rus' или 'eng')
-            to_deg (bool): Конвертировать в градусы
-            to_rad (bool): Конвертировать в радианы
-            figsize (tuple): Размер фигуры
+            output_name (str): Output name.
+            time (np.ndarray): Time vector.
+            lang (str): Axis label language ('rus' or 'eng').
+            to_deg (bool): Convert radians to degrees.
+            to_rad (bool): Convert degrees to radians.
+            figsize (tuple): Figure size.
 
         Returns:
-            matplotlib.figure.Figure: Объект фигуры matplotlib
-
-        Raises:
-            Exception: Если указаны одновременно to_rad и to_deg или неверное имя сигнала
-
-        Пример:
-            >>> fig = model.plot_output('alpha', time_array, lang='rus', to_deg=True)
+            matplotlib.figure.Figure: Figure object.
         """
         if to_rad and to_deg:
             raise Exception(
