@@ -1,3 +1,9 @@
+"""A3C (Asynchronous Advantage Actor-Critic) components.
+
+This package re-exports the primary A3C classes (agent, network, worker) for
+convenient access.
+"""
+
 from .pytorch import Agent as Agent  # noqa: F401
 from .pytorch import Net as Net  # noqa: F401
 from .pytorch import Worker as Worker  # noqa: F401
