@@ -1,3 +1,9 @@
+"""Model Predictive Control (MPC) agents.
+
+This package contains MPC-related agents and neural-network dynamics models
+used for control in TensorAeroSpace environments.
+"""
+
 from .base import AircraftMPC as AircraftMPC
 from .dynamics import DynamicsNN as DynamicsNN
 from .gradient import MPCOptimizationAgent as MPCOptimizationAgent
