@@ -1,3 +1,9 @@
+"""Soft Actor-Critic (SAC) components.
+
+This package re-exports policy and value network classes used by the SAC agent
+implementation.
+"""
+
 from .model import DeterministicPolicy as DeterministicPolicy
 from .model import GaussianPolicy as GaussianPolicy
 from .model import QNetwork as QNetwork
