@@ -1,5 +1,12 @@
+"""Boeing 747 Gymnasium environments.
+
+This module provides Gymnasium-compatible environments based on a B747
+longitudinal dynamics model, including a classic linear environment and an
+improved normalized variant.
+"""
+
 import os
-from typing import Any, Callable, Optional
+from typing import Any, Callable, Dict, Optional, Tuple
 
 import gymnasium as gym
 import numpy as np
@@ -242,7 +249,7 @@ class LinearLongitudinalB747(gym.Env):
             },
         )
 
-    def reset(self, seed=None, options=None):
+    def reset(self, seed=None, options=None) -> Tuple[np.ndarray, Dict[str, Any]]:
         """Reset simulation environment to initial conditions.
 
         Args:
