@@ -1,3 +1,12 @@
+"""Base interfaces for hyperparameter optimization backends.
+
+This module defines abstract interfaces and concrete implementations for
+hyperparameter search used across TensorAeroSpace (e.g., Optuna, Ray Tune).
+
+The intent is to provide a small, consistent API for running searches and
+extracting the best found configuration.
+"""
+
 from abc import ABC
 from typing import Callable
 
@@ -6,67 +15,73 @@ import optuna
 
 
 class HyperParamOptimizationBase(ABC):
-    """Interface class for hyperparameter search."""
+    """Base interface for hyperparameter search backends."""
 
     def __init__(self) -> None:
-        """Initialize."""
+        """Initialize the optimization backend."""
         pass
 
     def run_optimization(self):
-        """Run optimization."""
+        """Run the optimization procedure."""
         pass
 
     def get_best_param(self) -> dict:
-        """Get best found parameters.
+        """Return the best found hyperparameters.
 
         Returns:
-            dict: Best parameters.
+            dict: Best parameters found by the backend.
         """
         pass
 
     def plot_parms(self, fig_size):
-        """Plot optimization steps."""
+        """Plot optimization history.
+
+        Args:
+            fig_size: Figure size passed to the underlying plotting backend.
+        """
         pass
 
 
 class HyperParamOptimizationOptuna(HyperParamOptimizationBase):
-    """
-    Поиск гиперпараметров модели
-    """
+    """Hyperparameter optimization using Optuna."""
 
     def __init__(self, direction: str) -> None:
-        """Инициализация поиска гиперпараметров
+        """Create an Optuna study for hyperparameter optimization.
 
         Args:
-            direction (str): Направление поиска. Ex. minimize|maximize
+            direction: Optimization direction. One of ``'minimize'`` or
+                ``'maximize'``.
+
+        Raises:
+            ValueError: If ``direction`` is not supported.
         """
         super().__init__()
         if direction not in ["minimize", "maximize"]:
-            raise ValueError("Выберите один из вариантов minimize или maximize")
+            raise ValueError("direction must be 'minimize' or 'maximize'")
         self.study = optuna.create_study(direction=direction)
 
     def run_optimization(self, func: Callable, n_trials: int):
-        """Запуск поиска гиперпараметров
+        """Run hyperparameter search.
 
         Args:
-            func (void): Функция поиска параметров
-            n_trials (int): Количество попыток для поиска
+            func: Objective function to optimize.
+            n_trials: Number of trials to run.
         """
         self.study.optimize(func, n_trials=n_trials)
 
     def get_best_param(self) -> dict:
-        """Получить лучшие гиперпараметры
+        """Return the best hyperparameters found by Optuna.
 
         Returns:
-            dict: Словарь с лучшими гиперпараметрами
+            dict: Best hyperparameters.
         """
         return self.study.best_trial.params
 
     def plot_parms(self, figsize=(15, 5)):
-        """Построить график поиска гиперпараметров
+        """Plot trial values over the optimization history.
 
         Args:
-            figsize (tuple, optional): Размер графика. По умолчанию (15, 5).
+            figsize: Matplotlib figure size. Defaults to ``(15, 5)``.
         """
         x = []
         x_labels = []
@@ -80,6 +95,6 @@ class HyperParamOptimizationOptuna(HyperParamOptimizationBase):
         ax.plot(range(len(self.study.trials)), x)
         ax.set_xticks(range(len(self.study.trials)))
         ax.set_xticklabels(x_labels, rotation=90, multialignment="left")
-        ax.set_title("График поиска гиперпараметров")
+        ax.set_title("Hyperparameter search history")
         ax.set_ylabel("Значение функции", fontsize=15)
         ax.set_xlabel("Итерации", fontsize=15)
